@@ -1,9 +1,9 @@
 # IPC::Locker.pm -- distributed lock handler
-# $Id: PidServer.pm,v 1.4 2005/11/07 16:44:47 wsnyder Exp $
+# $Id: PidServer.pm,v 1.6 2006/03/13 15:56:13 wsnyder Exp $
 # Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
-# Copyright 1999-2003 by Wilson Snyder.  This program is free software;
+# Copyright 1999-2006 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 # 
@@ -34,7 +34,7 @@ use Carp;
 # Other configurable settings.
 $Debug = 0;
 
-$VERSION = '1.434';
+$VERSION = '1.440';
 
 $Hostname = hostname();
 
@@ -76,6 +76,10 @@ sub start_server {
 		my $out_msg = "EXIS $pid $exists $Hostname";  # PID response
 		print "   Send msg $out_msg\n" if $Debug;
 		$server->send($out_msg);  # or die... But we'll ignore errors
+	    } else {
+		my $out_msg = "UNKN $pid na $Hostname";  # PID response
+		print "   Send msg $out_msg\n" if $Debug;
+		$server->send($out_msg);  # or die... But we'll ignore errors
 	    }
 	}
     }
@@ -127,7 +131,7 @@ The port number (INET) or name (UNIX) of the lock server.  Defaults to
 
 The latest version is available from CPAN and from L<http://www.veripool.com/>.
 
-Copyright 2002-2004 by Wilson Snyder.  This package is free software; you
+Copyright 2002-2006 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License or the Perl Artistic License.
 
